/*-------------------------------------------------------------------------
 *
 * pg_description_d.h
 *    Macro definitions for pg_description
 *
 * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 * NOTES
 *  ******************************
 *  *** DO NOT EDIT THIS FILE! ***
 *  ******************************
 *
 *  It has been GENERATED by src/backend/catalog/genbki.pl
 *
 *-------------------------------------------------------------------------
 */
#ifndef PG_DESCRIPTION_D_H
#define PG_DESCRIPTION_D_H

#define DescriptionRelationId 2609
#define DescriptionObjIndexId 2675

#define Anum_pg_description_objoid 1
#define Anum_pg_description_classoid 2
#define Anum_pg_description_objsubid 3
#define Anum_pg_description_description 4

#define Natts_pg_description 4


#endif							/* PG_DESCRIPTION_D_H */
